finchan.interface.event_source
==================================

.. automodule:: finchan.interface.event_source

   AbsEventSource
   --------------------
   .. autoclass:: AbsEventSource
       :members:
